4.40. umbra.ui.completers — Umbra 1.0.8 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.8 documentation »
- 4. Api »

# 4.40. umbra.ui.completers

completers.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  This module defines the Application completers classes.
  Each completer class completion list is initialized only once per session and
  cached at the first class instantiation.

Others:

## 4.40.1. Module Attributes

`umbra.ui.completers.` `LOGGER`

## 4.40.2. Classes

class `umbra.ui.completers.` `DefaultCompleter`(parent=None, language=None, tokens=None)

  Bases: `PyQt4.QtGui.QCompleter`

  This class is a QCompleter subclass used as a completion widget.

  Parameters: | parent – Object parent. ( QObject ) language – Language name. ( String ) tokens – Completer tokens list. ( Tuple / List )

  `language`

    This method is the property for self.__language attribute.

    Returns: | self.__language. ( String )

  `updateModel`(words)

    This method updates the completer model.

    Parameters: | words – Words to update the completer with. ( Tuple / List )
    Returns: | Method success. ( Boolean )

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.8 documentation »
- 4. Api »